use warnings;
use strict;
package Test::Module 0.20180802; # TRIAL

# ABSTRACT: brief summary of what this module is used for

use Exporter 'import';
our (@EXPORT_OK) = ();
our (@EXPORT)    = (@EXPORT_OK);


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Test::Module - brief summary of what this module is used for

=head1 VERSION

version 0.20180802

=head1 SYNOPSIS

    use Test::Module;

    ## ... code that uses your package

=head1 AUTHOR

Balaji Ramasubramanian <balaji.ramasubramanian@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Balaji Ramasubramanian.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
